The ``linchpin`` CLI is used to perform tasks related to managing :term:`resources`. For detail about a specific command, see :doc:`../cli`.

Getting Help
````````````

.. include:: includes/cli_help.rst

.. _basic_usage:

Basic Usage
```````````

.. include:: includes/cli_basic_usage.rst

.. _opts_args:

Options and Arguments
`````````````````````

.. include:: includes/cli_opts_args.rst

.. _combining_options:

Combining Options
`````````````````

.. include:: includes/cli_combine_opts.rst

.. _common_usage:

Common Usage
````````````

.. include:: includes/cli_common_usage.rst

